<?php
/*
Plugin Name: Easy Similar Posts
Plugin URI: http://thisismyurl.com/downloads/easy-similar-posts/
Description: An easy to use WordPress function to add Similar Posts to any theme.
Author: Christopher Ross
Author URI: http://thisismyurl.com/
Tags: future, upcoming posts, upcoming post, upcoming, draft, Post, similar, preview, plugin, post, posts
Version: 15.01
*/


/**
 *
 * Easy Similar Posts core file
 *
 * This file contains all the logic required for the plugin
 *
 * @link		http://wordpress.org/extend/plugins/wordpresscom-stats-smiley-remover/
 *
 * @package 	Easy Similar Posts
 * @copyright	Copyright (c) 2008, Chrsitopher Ross
 * @license		http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU General Public License, v2 (or newer)
 *
 * @since 		Easy Similar Posts 1.0
 *
 *
 */

/* if the plugin is called directly, die */
if ( ! defined( 'WPINC' ) )
	die;
	
	
define( 'THISISMYURL_ESIP_NAME', 'Easy Similar Posts' );
define( 'THISISMYURL_ESIP_SHORTNAME', 'Easy Similar Posts' );

define( 'THISISMYURL_ESIP_FILENAME', plugin_basename( __FILE__ ) );
define( 'THISISMYURL_ESIP_FILEPATH', dirname( plugin_basename( __FILE__ ) ) );
define( 'THISISMYURL_ESIP_FILEPATHURL', plugin_dir_url( __FILE__ ) );

define( 'THISISMYURL_ESIP_NAMESPACE', basename( THISISMYURL_ESIP_FILENAME, '.php' ) );
define( 'THISISMYURL_ESIP_TEXTDOMAIN', str_replace( '-', '_', THISISMYURL_ESIP_NAMESPACE ) );

define( 'THISISMYURL_ESIP_VERSION', '15.01' );

include_once( 'thisismyurl-common.php' );

/**
 * Creates the class required for Easy Similar Posts
 *
 * @author     Christopher Ross <info@thisismyurl.com>
 * @version    Release: @15.01@
 * @see        wp_enqueue_scripts()
 * @since      Class available since Release 14.11
 *
 */
if( ! class_exists( 'thissimyurl_EasySimilarPosts' ) ) {
class thissimyurl_EasySimilarPosts extends thisismyurl_Common_ESIP {
	/**
	  * Standard Constructor
	  *
	  * @access public
	  * @static
	  * @uses http://codex.wordpress.org/Function_Reference/add_shortcode
	  * @since Method available since Release 15.01
	  *
	  */
	public function run() {
		
		add_action( 'widgets_init', array( $this, 'widget_init' ) );
		
		add_shortcode( 'thisismyurl_easy_similar_posts', array( $this, 'easy_similar_posts_shortcode' ) );
		
	}
	
	
	
	/**
	  * easy_similar_posts_shortcode helper function
	  *
	  * @access public
	  * @static
	  * @since Method available since Release 14.11
	  *
	  */
	 function easy_similar_posts_shortcode() {
	
		$similar_posts = $this->easy_similar_posts();
		
		if ( ! empty( $similar_posts ) )
			echo '<ul class="thisismyurl-easy-similar-posts">' . $similar_posts . '</ul>';
			
	} 
	
	
	
	/**
	  * easy_similar_posts
	  *
	  * @access public
	  * @static
	  * @since Method available since Release 14.11
	  *
	  */
	function easy_similar_posts( $options = NULL ) {

		global $post;
		
		$options = wp_parse_args( $this->similar_posts_defaults(), $options );
		
		if( is_single() ) {
			
			$post_tags = wp_get_post_tags( $post->ID );
			if ( $post_tags ) {
				
				$individual_post_tag_ids = array();
				foreach( $post_tags as $individual_post_tag ) {
					$individual_post_tag_ids[] = $individual_post_tag->term_id;
				}
				
			}
			
			$args = array( 	'numberposts' => $options['post_count'], 
							'orderby' => $options['order'], 
							'exclude' => $post->ID
					);
					
			if ( isset( $individual_post_tag_ids ) )
				$args['tag__in'] = $individual_post_tag_ids;
			
			if ( ! empty( $args['tag__in'] ) )	
				$similar_posts = get_posts( $args );
			
		}
		
		if( isset( $similar_posts ) && ! empty( $similar_posts ) ) {
			foreach ( $similar_posts as $similar_post ) {
	
				/* place the post title */
				$similar_item = sprintf( '<span class="title">%s</span>', esc_html( get_the_title( $similar_post->ID ) ) );
				
				
				/* if there's a link, display it */
				if ( $options['include_link'] == 1 ) {
				
					if( $options['nofollow'] == 1 )
						$nofollow = 'nofollow';
					else
						$nofollow = '';
						
					$similar_item = sprintf( '<span class="title-link"><a href="%s" title="%s" %s >%s</a><span>',
											get_permalink( $similar_post->ID ),
											esc_attr( get_the_title( $similar_post->ID ) ),
											$nofollow,
											$similar_item
									);	
					
				}
				
				
				/* feature image, if there is one */
				if ( $options['feature_image'] == 1 && has_post_thumbnail( $similar_post->ID ) ) {
					$similar_item = sprintf( '<div class="thumbnail">%s</div>%s', 
											get_the_post_thumbnail($thepost->ID,'thumbnail'),
											$similar_item
											);
				}
				
				
				/* show the excerpt when it's required */
				if ( $options['show_excerpt'] == 1 && ! empty( $similar_post->post_excerpt ) ) {
					
					$similar_item = sprintf( '%s<div class="excerpt">%s</div>', 
											$similar_item,
											esc_html( $similar_post->post_excerpt )
											);
				}
				
	
				/* wrap the content in the proper tags */
				$similar[] =  $options['before'] . $similar_item . $options['after'];
		
			}
	
		}
		
		/* return in the proper format */
		if ( ! empty( $similar ) ) {
			if ( $options['show'] == 1 )
				echo implode( '', $similar );
			else
				return implode( '', $similar );
		
		}
	
	}
	
	/**
	  * similar_posts_defaults sets defaults for plugin
	  *
	  * @access public
	  * @static
	  * @since Method available since Release 14.11
	  *
	  */	 
	function similar_posts_defaults() {
	
		$default_options = array(
									'title'     	=> __( 'Easy Similar Posts', THISISMYURL_ESIP_NAME ),
									'post_count'    => 10,
									'order'    		=> 'RAND',
									'include_link' 	=> 1,
									'before'   		=> '<li>',
									'after'    		=> '</li>',
									'nofollow' 		=> 0,
									'show_excerpt' 	=> 0,
									'feature_image' => 0,
									'show_credit' 	=> 1,
									'show'     		=> 0,
									
								);
								
		return $default_options;						
								
	}
	
	
	
	/**
	  * widget_init activates the plugin widgets
	  *
	  * @access public
	  * @static
	  * @uses register_widget
	  * @since Method available since Release 15.01
	  *
	  */
	function widget_init() {
		
		include_once( 'widgets/thissimyurl_EasySimilarPosts_Widget.php' );
		register_widget( 'thissimyurl_EasySimilarPosts_Widget' );
	
	}

	  
	
}
}

global $thissimyurl_EasySimilarPosts;

$thissimyurl_EasySimilarPosts = new thissimyurl_EasySimilarPosts;

$thissimyurl_EasySimilarPosts->run();




/**
  * Allows theme authors to call 
  *
  * @access public
  * @static
  * @uses $thissimyurl_EasySimilarPosts->easy_similar_posts
  * @since Method available since Release 15.01
  *
  * @param  array see $thissimyurl_EasySimilarPosts->similar_posts_defaults() for accepted options
  *
  */
if ( ! function_exists( 'thisismyurl_easy_similar_posts' ) ) {
function thisismyurl_easy_similar_posts( $options = NULL ) {
	
	$thissimyurl_EasySimilarPosts->easy_similar_posts( $options );

}
}